@@ -172,10 +172,10 @@ void Account::handleReply(QNetworkReply *reply, std::function<void(QNetworkReply
     connect(reply, &QNetworkReply::finished, [reply, reply_cb, errorCallback]() {
         reply->deleteLater();
         if (200 != reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) && !reply->url().toString().contains("nodeinfo"_L1)) {
-            qCWarning(TOKODON_HTTP) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << reply->url();
             if (errorCallback) {
                 errorCallback(reply);
             } else {
+                qCWarning(TOKODON_HTTP) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << reply->url();
                 Q_EMIT NetworkController::instance().networkErrorOccurred(reply->errorString());
             }
             return;
@@ -214,6 +214,17 @@ QNetworkReply *Account::upload(const QUrl &filename, std::function<void(QNetwork
     return post(uploadUrl, mp, true, this, callback);
 }
 
+void Account::requestRemoteObject(const QUrl &remoteUrl, QObject *parent, std::function<void(QNetworkReply *)> callback)
+{
+    auto url = apiUrl(QStringLiteral("/api/v2/search"));
+    url.setQuery({
+        {QStringLiteral("q"), remoteUrl.toString()},
+        {QStringLiteral("resolve"), QStringLiteral("true")},
+        {QStringLiteral("limit"), QStringLiteral("1")},
+    });
+    get(url, true, parent, std::move(callback));
+}
+
 static QMap<QString, AbstractAccount::StreamingEventType> stringToStreamingEventType = {
     {QStringLiteral("update"), AbstractAccount::StreamingEventType::UpdateEvent},
     {QStringLiteral("delete"), AbstractAccount::StreamingEventType::DeleteEvent},
