@@ -190,7 +190,7 @@ void AccountManager::removeAccount(AbstractAccount *account)
     endRemoveRows();
 
     if (hasAccounts()) {
-        m_selected_account = m_accounts[0];
+        m_selected_account = m_accounts.first();
     } else {
         m_selected_account = nullptr;
     }
@@ -216,8 +216,16 @@ bool AccountManager::selectedAccountHasIssue() const
     if (!m_selected_account) {
         return false;
     }
+    return accountHasIssue(m_selected_account);
+}
 
-    const int index = m_accounts.indexOf(m_selected_account);
+bool AccountManager::accountHasIssue(AbstractAccount *account) const
+{
+    if (!m_selected_account) {
+        return false;
+    }
+
+    const int index = m_accounts.indexOf(account);
     if (index != -1 && index < m_accountStatus.size()) {
         return m_accountStatus[index] == AccountStatus::InvalidCredentials;
     }
@@ -379,6 +387,8 @@ bool AccountManager::isReady() const
 
 QString AccountManager::settingsGroupName(const QString &name, const QString &instanceUri)
 {
+    Q_ASSERT(!name.isEmpty());
+    Q_ASSERT(!instanceUri.isEmpty());
     return name + QLatin1Char('@') + QUrl(instanceUri).host();
 }
 
