@@ -2,6 +2,7 @@
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include <QQuickStyle>
+#include <QQuickWindow>
 
 #ifdef HAVE_WEBVIEW
 #include <QtWebView>
@@ -110,7 +111,7 @@ int main(int argc, char *argv[])
                      QStringLiteral(TOKODON_VERSION_STRING),
                      i18n("Mastodon client"),
                      KAboutLicense::GPL_V3,
-                     i18n("© 2021-2023 Carl Schwan, 2021-2023 KDE Community"));
+                     i18n("© 2021-2024 Carl Schwan, 2021-2024 KDE Community"));
     about.addAuthor(i18n("Carl Schwan"),
                     i18n("Maintainer"),
                     QStringLiteral("carl@carlschwan.eu"),
@@ -248,6 +249,12 @@ int main(int argc, char *argv[])
     AccountManager::instance().loadFromSettings();
 #endif
 
+    // If this isn't initialized previous on Android, it crashes??
+    // TODO: investigate why does this happen
+#ifdef Q_OS_ANDROID
+    Q_UNUSED(NetworkController::instance());
+#endif
+
     if (parser.isSet(shareOption)) {
         engine.loadFromModule("org.kde.tokodon", "StandaloneComposer");
 
