@@ -1,7 +1,7 @@
 // SPDX-FileCopyrightText: 2023 Shubham Arora <shubhamarora@protonmail.com>
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-#include "tagsmodel.h"
+#include "timeline/tagsmodel.h"
 
 #include <KLocalizedString>
 
